<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory.stock');

// 记录访问日志
record_log('访问库存管理页面');

// 添加/编辑库存处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加库存
    if ($_POST['action'] == 'add') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '';
        $stock = isset($_POST['stock']) ? floatval($_POST['stock']) : 0;
        $min_stock = isset($_POST['min_stock']) ? floatval($_POST['min_stock']) : 0;
        $cost_price = isset($_POST['cost_price']) ? floatval($_POST['cost_price']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($name) || empty($category) || empty($unit)) {
            $error = '请填写完整库存信息！';
        } else {
            try {
                // 检查原料名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inv_material WHERE name = ? AND store_id = ?");
                $stmt->execute([$name, $store_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '原料名称已存在！';
                } else {
                    // 添加原料
                    $stmt = $pdo->prepare("INSERT INTO inv_material (store_id, name, category, unit, stock, min_stock, cost_price, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$store_id, $name, $category, $unit, $stock, $min_stock, $cost_price, $status]);

                    if ($result) {
                        record_log("添加原料：{$name}");
                        $success = '原料添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: stock.php?success=add');
                        exit;
                    } else {
                        $error = '原料添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑原料
    elseif ($_POST['action'] == 'edit') {
        $material_id = isset($_POST['material_id']) ? intval($_POST['material_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '';
        $stock = isset($_POST['stock']) ? floatval($_POST['stock']) : 0;
        $min_stock = isset($_POST['min_stock']) ? floatval($_POST['min_stock']) : 0;
        $cost_price = isset($_POST['cost_price']) ? floatval($_POST['cost_price']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($material_id <= 0 || empty($name) || empty($category) || empty($unit)) {
            $error = '请填写完整原料信息！';
        } else {
            try {
                // 检查原料名称是否已被其他原料使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inv_material WHERE name = ? AND id != ? AND store_id = ?");
                $stmt->execute([$name, $material_id, $store_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '原料名称已被使用！';
                } else {
                    // 更新原料信息
                    $stmt = $pdo->prepare("UPDATE inv_material SET store_id = ?, name = ?, category = ?, unit = ?, stock = ?, min_stock = ?, cost_price = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$store_id, $name, $category, $unit, $stock, $min_stock, $cost_price, $status, $material_id]);

                    if ($result) {
                        record_log("编辑原料：{$name}");
                        $success = '原料信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: stock.php?success=edit');
                        exit;
                    } else {
                        $error = '原料信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除原料
    elseif ($_POST['action'] == 'delete') {
        $material_id = isset($_POST['material_id']) ? intval($_POST['material_id']) : 0;

        if ($material_id <= 0) {
            $error = '无效的原料ID！';
        } else {
            try {
                // 获取原料名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM inv_material WHERE id = ?");
                $stmt->execute([$material_id]);
                $material = $stmt->fetch();

                if (!$material) {
                    $error = '原料不存在！';
                } else {
                    // 检查原料是否有关联库存记录
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM inv_record WHERE material_id = ?");
                    $stmt->execute([$material_id]);
                    $record_count = $stmt->fetch();

                    if ($record_count['count'] > 0) {
                        $error = '该原料存在库存记录，无法删除！';
                    } else {
                        // 删除原料
                        $stmt = $pdo->prepare("DELETE FROM inv_material WHERE id = ?");
                        $result = $stmt->execute([$material_id]);

                        if ($result) {
                            record_log("删除原料：{$material['name']}");
                            $success = '原料删除成功！';
                        } else {
                            $error = '原料删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有门店
try {
    $stmt = $pdo->query("SELECT * FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 获取所有原料
try {
    $stmt = $pdo->query("
        SELECT m.*, s.store_name 
        FROM inv_material m
        LEFT JOIN store_info s ON m.store_id = s.id
        ORDER BY m.id DESC
    ");
    $materials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取原料列表失败：' . $e->getMessage();
    $materials = [];
}

// 判断是否显示表单
$show_form = false;
$edit_material = null;

// 编辑原料时显示表单并获取原料信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM inv_material WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_material = $stmt->fetch();
        if (!$edit_material) {
            $error = '原料不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取原料信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加原料时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '原料添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '原料信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>库存管理</h2>
            <div class="breadcrumb">
                <a href="index.php">库存管理</a> &gt; 原料库存
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="stock.php?action=add" class="btn btn-add">添加原料</a>
            </div>

            <!-- 添加/编辑原料表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_material ? '编辑原料' : '添加原料'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_material ? 'edit' : 'add'; ?>">
                        <?php if ($edit_material): ?>
                            <input type="hidden" name="material_id" value="<?php echo $edit_material['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">所属门店：</label>
                            <select id="store_id" name="store_id">
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($edit_material && $edit_material['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">原料名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_material ? htmlspecialchars($edit_material['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="category">原料类别：</label>
                            <input type="text" id="category" name="category" value="<?php echo $edit_material ? htmlspecialchars($edit_material['category']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="unit">单位：</label>
                            <input type="text" id="unit" name="unit" value="<?php echo $edit_material ? htmlspecialchars($edit_material['unit']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="stock">当前库存：</label>
                            <input type="number" id="stock" name="stock" min="0" step="0.01" value="<?php echo $edit_material ? htmlspecialchars($edit_material['stock']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="min_stock">最低库存：</label>
                            <input type="number" id="min_stock" name="min_stock" min="0" step="0.01" value="<?php echo $edit_material ? htmlspecialchars($edit_material['min_stock']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="cost_price">成本价格：</label>
                            <input type="number" id="cost_price" name="cost_price" min="0" step="0.01" value="<?php echo $edit_material ? htmlspecialchars($edit_material['cost_price']) : '0.00'; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_material && $edit_material['status'] == 1) ? 'selected' : ''; ?>>正常</option>
                                <option value="0" <?php echo ($edit_material && $edit_material['status'] == 0) ? 'selected' : ''; ?>>停用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="stock.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 原料库存列表 -->
            <div class="table-container">
                <h3>原料库存列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>所属门店</th>
                            <th>原料名称</th>
                            <th>类别</th>
                            <th>当前库存</th>
                            <th>最低库存</th>
                            <th>单位</th>
                            <th>成本价</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($materials)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无原料数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($materials as $material): ?>
                                <tr <?php echo ($material['stock'] < $material['min_stock']) ? 'class="status-inactive"' : ''; ?>>
                                    <td><?php echo $material['id']; ?></td>
                                    <td><?php echo htmlspecialchars($material['store_name']); ?></td>
                                    <td><?php echo htmlspecialchars($material['name']); ?></td>
                                    <td><?php echo htmlspecialchars($material['category']); ?></td>
                                    <td>
                                        <?php
                                        echo number_format($material['stock'], 2);
                                        if ($material['stock'] < $material['min_stock']) {
                                            echo ' <span class="status-inactive">库存不足</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo number_format($material['min_stock'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($material['unit']); ?></td>
                                    <td><?php echo number_format($material['cost_price'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($material['status'] == 1) echo '<span class="status-active">正常</span>';
                                        else echo '<span class="status-inactive">停用</span>';
                                        ?>
                                    </td>
                                    <td>
                                        <a href="stock.php?action=edit&id=<?php echo $material['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="material_id" value="<?php echo $material['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除原料 \'<?php echo htmlspecialchars($material['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>