<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member.info');

// 记录访问日志
record_log('访问会员管理页面');

// 初始化变量
$view_records = false;
$member_records = [];
$view_member = null;

// 处理查看会员记录
if (isset($_GET['view_records']) && isset($_GET['member_id'])) {
    $view_records = true;
    $member_id = intval($_GET['member_id']);

    try {
        // 获取会员信息
        $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
        $stmt->execute([$member_id]);
        $view_member = $stmt->fetch();

        if ($view_member) {
            // 获取会员交易记录
            $stmt = $pdo->prepare("
                SELECT r.*, o.order_no 
                FROM mem_record r
                LEFT JOIN order_main o ON r.order_id = o.id
                WHERE r.member_id = ?
                ORDER BY r.create_time DESC
            ");
            $stmt->execute([$member_id]);
            $member_records = $stmt->fetchAll();
        } else {
            $error = '会员不存在！';
            $view_records = false;
        }
    } catch (PDOException $e) {
        $error = '获取会员记录失败：' . $e->getMessage();
        $view_records = false;
    }
}

// 添加/编辑会员处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 处理会员积分余额变动记录
    if ($_POST['action'] == 'add_record') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $type = isset($_POST['type']) ? intval($_POST['type']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($member_id <= 0 || $type <= 0 || $amount <= 0) {
            $error = '请填写完整记录信息！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 添加交易记录
                $stmt = $pdo->prepare("INSERT INTO mem_record (member_id, type, amount, remark, create_time) VALUES (?, ?, ?, ?, NOW())");
                $result = $stmt->execute([$member_id, $type, $amount, $remark]);

                if ($result) {
                    // 更新会员信息
                    if ($type == 1) { // 积分增加
                        $stmt = $pdo->prepare("UPDATE mem_info SET points = points + ? WHERE id = ?");
                        $stmt->execute([$amount, $member_id]);
                    } elseif ($type == 2) { // 积分消费
                        // 检查积分是否足够
                        $stmt = $pdo->prepare("SELECT points FROM mem_info WHERE id = ?");
                        $stmt->execute([$member_id]);
                        $points_info = $stmt->fetch();

                        if ($points_info['points'] < $amount) {
                            throw new Exception('会员积分不足！');
                        }

                        $stmt = $pdo->prepare("UPDATE mem_info SET points = points - ? WHERE id = ?");
                        $stmt->execute([$amount, $member_id]);
                    } elseif ($type == 3) { // 余额充值
                        $stmt = $pdo->prepare("UPDATE mem_info SET balance = balance + ? WHERE id = ?");
                        $stmt->execute([$amount, $member_id]);
                    } elseif ($type == 4) { // 余额消费
                        // 检查余额是否足够
                        $stmt = $pdo->prepare("SELECT balance FROM mem_info WHERE id = ?");
                        $stmt->execute([$member_id]);
                        $balance_info = $stmt->fetch();

                        if ($balance_info['balance'] < $amount) {
                            throw new Exception('会员余额不足！');
                        }

                        $stmt = $pdo->prepare("UPDATE mem_info SET balance = balance - ? WHERE id = ?");
                        $stmt->execute([$amount, $member_id]);
                    }

                    // 提交事务
                    $pdo->commit();

                    record_log("添加会员交易记录：会员ID={$member_id}, 类型={$type}, 数量={$amount}");
                    $success = '交易记录添加成功！';
                    // 重定向到会员列表页面
                    header("Location: info.php?success=add_record");
                    exit;
                } else {
                    throw new Exception('添加交易记录失败！');
                }
            } catch (Exception $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = $e->getMessage();
            }
        }
    }

    // 添加会员
    if ($_POST['action'] == 'add') {
        $member_no = isset($_POST['member_no']) ? trim($_POST['member_no']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $birthday = isset($_POST['birthday']) && !empty($_POST['birthday']) ? trim($_POST['birthday']) : null;
        $level = isset($_POST['level']) ? intval($_POST['level']) : 1;
        $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
        $balance = isset($_POST['balance']) ? floatval($_POST['balance']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($phone)) {
            $error = '请填写会员手机号！';
        } else {
            try {
                // 检查手机号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM mem_info WHERE phone = ?");
                $stmt->execute([$phone]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该手机号已被注册！';
                } else {
                    // 如果未提供会员编号，则自动生成
                    if (empty($member_no)) {
                        $prefix = 'M' . date('Ym');

                        // 获取当前最大会员编号
                        $stmt = $pdo->prepare("SELECT MAX(member_no) as max_no FROM mem_info WHERE member_no LIKE ?");
                        $stmt->execute([$prefix . '%']);
                        $result = $stmt->fetch();

                        if ($result && $result['max_no']) {
                            $number = intval(substr($result['max_no'], -4)) + 1;
                        } else {
                            $number = 1;
                        }

                        $member_no = $prefix . str_pad($number, 4, '0', STR_PAD_LEFT);
                    }

                    // 添加会员
                    $stmt = $pdo->prepare("INSERT INTO mem_info (member_no, name, phone, birthday, level, points, balance, status) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$member_no, $name, $phone, $birthday, $level, $points, $balance, $status]);

                    if ($result) {
                        record_log("添加会员：{$phone}");
                        $success = '会员添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: info.php?success=add');
                        exit;
                    } else {
                        $error = '会员添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑会员
    elseif ($_POST['action'] == 'edit') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $birthday = isset($_POST['birthday']) && !empty($_POST['birthday']) ? trim($_POST['birthday']) : null;
        $level = isset($_POST['level']) ? intval($_POST['level']) : 1;
        $points = isset($_POST['points']) ? intval($_POST['points']) : 0;
        $balance = isset($_POST['balance']) ? floatval($_POST['balance']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($member_id <= 0 || empty($phone)) {
            $error = '请填写完整会员信息！';
        } else {
            try {
                // 检查手机号是否已被其他会员使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM mem_info WHERE phone = ? AND id != ?");
                $stmt->execute([$phone, $member_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该手机号已被其他会员使用！';
                } else {
                    // 更新会员信息
                    $stmt = $pdo->prepare("UPDATE mem_info SET name = ?, phone = ?, birthday = ?, level = ?, points = ?, balance = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$name, $phone, $birthday, $level, $points, $balance, $status, $member_id]);

                    if ($result) {
                        record_log("编辑会员：{$phone}");
                        $success = '会员信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: info.php?success=edit');
                        exit;
                    } else {
                        $error = '会员信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除会员
    elseif ($_POST['action'] == 'delete') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;

        if ($member_id <= 0) {
            $error = '无效的会员ID！';
        } else {
            try {
                // 获取会员信息，用于日志记录
                $stmt = $pdo->prepare("SELECT phone FROM mem_info WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    $error = '会员不存在！';
                } else {
                    // 检查会员是否有关联订单
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM order_main WHERE member_id = ?");
                    $stmt->execute([$member_id]);
                    $order_count = $stmt->fetch();

                    if ($order_count['count'] > 0) {
                        $error = '该会员存在订单记录，无法删除！可以将状态设置为"禁用"。';
                    } else {
                        // 检查会员是否有余额或积分
                        $stmt = $pdo->prepare("SELECT balance, points FROM mem_info WHERE id = ?");
                        $stmt->execute([$member_id]);
                        $balance_info = $stmt->fetch();

                        if ($balance_info['balance'] > 0 || $balance_info['points'] > 0) {
                            $error = '该会员账户中还有余额或积分，无法删除！';
                        } else {
                            // 删除会员
                            $stmt = $pdo->prepare("DELETE FROM mem_info WHERE id = ?");
                            $result = $stmt->execute([$member_id]);

                            if ($result) {
                                record_log("删除会员：{$member['phone']}");
                                $success = '会员删除成功！';
                            } else {
                                $error = '会员删除失败！';
                            }
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有会员
try {
    $sql = "SELECT * FROM mem_info ORDER BY id DESC";
    $stmt = $pdo->query($sql);
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
    $members = [];
}

// 判断是否显示表单
$show_form = false;
$edit_member = null;

// 编辑会员时显示表单并获取会员信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_member = $stmt->fetch();
        if (!$edit_member) {
            $error = '会员不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取会员信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加会员时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '会员添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '会员信息更新成功！';
    } elseif ($_GET['success'] == 'add_record') {
        $success = '会员交易记录添加成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员营销</a> &gt; 会员管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 会员交易记录视图 -->
            <?php if ($view_records && $view_member): ?>
                <div class="action-bar">
                    <a href="info.php" class="btn btn-secondary">返回会员列表</a>
                    <a href="#add-record" class="btn btn-add">添加交易记录</a>
                </div>

                <div class="form-container" id="add-record">
                    <h3>添加会员交易记录</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add_record">
                        <input type="hidden" name="member_id" value="<?php echo $view_member['id']; ?>">

                        <div class="form-group">
                            <label>会员：</label>
                            <div><?php echo htmlspecialchars($view_member['name'] ? $view_member['name'] : $view_member['phone']); ?> (<?php echo htmlspecialchars($view_member['member_no']); ?>)</div>
                        </div>

                        <div class="form-group">
                            <label>当前积分：</label>
                            <div><?php echo number_format($view_member['points']); ?></div>
                        </div>

                        <div class="form-group">
                            <label>当前余额：</label>
                            <div><?php echo number_format($view_member['balance'], 2); ?> 元</div>
                        </div>

                        <div class="form-group">
                            <label for="type">交易类型：</label>
                            <select id="type" name="type" required>
                                <option value="">请选择</option>
                                <option value="1">积分增加</option>
                                <option value="2">积分消费</option>
                                <option value="3">余额充值</option>
                                <option value="4">余额消费</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">数量/金额：</label>
                            <input type="number" id="amount" name="amount" min="0.01" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="2"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="info.php?view_records=1&member_id=<?php echo $view_member['id']; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>会员交易记录 - <?php echo htmlspecialchars($view_member['name'] ? $view_member['name'] : $view_member['phone']); ?> (<?php echo htmlspecialchars($view_member['member_no']); ?>)</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>交易类型</th>
                                <th>数量/金额</th>
                                <th>关联订单</th>
                                <th>备注</th>
                                <th>交易时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($member_records)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无交易记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($member_records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td>
                                            <?php
                                            if ($record['type'] == 1) echo '<span class="status-active">积分增加</span>';
                                            elseif ($record['type'] == 2) echo '<span class="status-inactive">积分消费</span>';
                                            elseif ($record['type'] == 3) echo '<span class="status-active">余额充值</span>';
                                            elseif ($record['type'] == 4) echo '<span class="status-inactive">余额消费</span>';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($record['type'] == 1 || $record['type'] == 2) {
                                                echo number_format($record['amount']) . ' 分';
                                            } else {
                                                echo number_format($record['amount'], 2) . ' 元';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo $record['order_no'] ? htmlspecialchars($record['order_no']) : '-'; ?></td>
                                        <td><?php echo htmlspecialchars($record['remark'] ?: '-'); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <div class="action-bar">
                    <a href="info.php?action=add" class="btn btn-add">添加会员</a>
                </div>

                <!-- 添加/编辑会员表单 -->
                <?php if ($show_form): ?>
                    <div class="form-container">
                        <h3><?php echo $edit_member ? '编辑会员' : '添加会员'; ?></h3>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="<?php echo $edit_member ? 'edit' : 'add'; ?>">
                            <?php if ($edit_member): ?>
                                <input type="hidden" name="member_id" value="<?php echo $edit_member['id']; ?>">
                            <?php endif; ?>

                            <?php if ($edit_member): ?>
                                <div class="form-group">
                                    <label for="member_no">会员编号：</label>
                                    <input type="text" id="member_no" value="<?php echo htmlspecialchars($edit_member['member_no']); ?>" readonly>
                                    <small>会员编号不可修改</small>
                                </div>
                            <?php else: ?>
                                <div class="form-group">
                                    <label for="member_no">会员编号：</label>
                                    <input type="text" id="member_no" name="member_no" placeholder="留空将自动生成">
                                    <small>可选，留空将自动生成</small>
                                </div>
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="name">会员姓名：</label>
                                <input type="text" id="name" name="name" value="<?php echo $edit_member ? htmlspecialchars($edit_member['name']) : ''; ?>">
                            </div>

                            <div class="form-group">
                                <label for="phone">手机号码：</label>
                                <input type="text" id="phone" name="phone" value="<?php echo $edit_member ? htmlspecialchars($edit_member['phone']) : ''; ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="birthday">生日：</label>
                                <input type="date" id="birthday" name="birthday" value="<?php echo $edit_member ? htmlspecialchars($edit_member['birthday']) : ''; ?>">
                            </div>

                            <div class="form-group">
                                <label for="level">会员等级：</label>
                                <select id="level" name="level">
                                    <option value="1" <?php echo ($edit_member && $edit_member['level'] == 1) ? 'selected' : ''; ?>>普通会员</option>
                                    <option value="2" <?php echo ($edit_member && $edit_member['level'] == 2) ? 'selected' : ''; ?>>银卡会员</option>
                                    <option value="3" <?php echo ($edit_member && $edit_member['level'] == 3) ? 'selected' : ''; ?>>金卡会员</option>
                                    <option value="4" <?php echo ($edit_member && $edit_member['level'] == 4) ? 'selected' : ''; ?>>黑卡会员</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="points">积分余额：</label>
                                <input type="number" id="points" name="points" min="0" value="<?php echo $edit_member ? intval($edit_member['points']) : '0'; ?>">
                            </div>

                            <div class="form-group">
                                <label for="balance">账户余额：</label>
                                <input type="number" id="balance" name="balance" min="0" step="0.01" value="<?php echo $edit_member ? number_format($edit_member['balance'], 2, '.', '') : '0.00'; ?>">
                            </div>

                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_member && $edit_member['status'] == 1) ? 'selected' : ''; ?>>正常</option>
                                    <option value="0" <?php echo ($edit_member && $edit_member['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>

                            <?php if ($edit_member): ?>
                                <div class="form-group">
                                    <label>累计消费：</label>
                                    <div><?php echo number_format($edit_member['total_amount'], 2); ?> 元</div>
                                </div>

                                <div class="form-group">
                                    <label>注册时间：</label>
                                    <div><?php echo date('Y-m-d H:i', strtotime($edit_member['create_time'])); ?></div>
                                </div>
                            <?php endif; ?>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-success">保存</button>
                                <a href="info.php" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>

                <!-- 会员列表 -->
                <div class="table-container">
                    <h3>会员列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员编号</th>
                                <th>姓名</th>
                                <th>手机号码</th>
                                <th>会员等级</th>
                                <th>积分</th>
                                <th>账户余额</th>
                                <th>累计消费</th>
                                <th>生日</th>
                                <th>状态</th>
                                <th>注册时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($members)): ?>
                                <tr>
                                    <td colspan="12" class="text-center">暂无会员数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($members as $member): ?>
                                    <tr>
                                        <td><?php echo $member['id']; ?></td>
                                        <td><?php echo htmlspecialchars($member['member_no']); ?></td>
                                        <td><?php echo htmlspecialchars($member['name'] ?: '-'); ?></td>
                                        <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                        <td>
                                            <?php
                                            if ($member['level'] == 1) echo '普通会员';
                                            elseif ($member['level'] == 2) echo '银卡会员';
                                            elseif ($member['level'] == 3) echo '金卡会员';
                                            elseif ($member['level'] == 4) echo '黑卡会员';
                                            ?>
                                        </td>
                                        <td><?php echo number_format($member['points']); ?></td>
                                        <td><?php echo number_format($member['balance'], 2); ?></td>
                                        <td><?php echo number_format($member['total_amount'], 2); ?></td>
                                        <td><?php echo $member['birthday'] ? date('Y-m-d', strtotime($member['birthday'])) : '-'; ?></td>
                                        <td>
                                            <?php
                                            if ($member['status'] == 1) echo '<span class="status-active">正常</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($member['create_time'])); ?></td>
                                        <td>
                                            <a href="info.php?view_records=1&member_id=<?php echo $member['id']; ?>" class="btn btn-sm btn-details">记录</a>
                                            <a href="info.php?action=edit&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="member_id" value="<?php echo $member['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除会员 \'<?php echo htmlspecialchars($member['phone']); ?>\' 吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>