<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order.payment');

// 记录访问日志
record_log('访问订单支付页面');

// 获取订单ID
$order_id = isset($_GET['order_id']) ? intval($_GET['order_id']) : 0;

// 处理支付提交
$payment_success = false;
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'pay') {
    $pay_type = isset($_POST['pay_type']) ? intval($_POST['pay_type']) : 0;
    $pay_amount = isset($_POST['pay_amount']) ? floatval($_POST['pay_amount']) : 0;
    $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;

    if ($pay_type == 0) {
        $error = '请选择支付方式';
    } elseif ($pay_amount <= 0) {
        $error = '支付金额必须大于0';
    } else {
        try {
            // 开始事务
            $pdo->beginTransaction();

            // 生成支付流水号
            $pay_no = 'P' . date('YmdHis') . rand(1000, 9999);

            // 如果是会员余额支付，检查余额是否充足
            if ($pay_type == 5 && $member_id > 0) {
                $stmt = $pdo->prepare("SELECT balance FROM mem_info WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    throw new Exception('会员信息不存在');
                }

                if ($member['balance'] < $pay_amount) {
                    throw new Exception('会员余额不足，请选择其他支付方式');
                }

                // 扣减会员余额
                $stmt = $pdo->prepare("UPDATE mem_info SET balance = balance - ? WHERE id = ?");
                $stmt->execute([$pay_amount, $member_id]);

                // 记录会员交易
                $stmt = $pdo->prepare("INSERT INTO mem_record (member_id, type, amount, order_id, remark) VALUES (?, 4, ?, ?, '订单消费')");
                $stmt->execute([$member_id, $pay_amount, $order_id]);
            }

            // 插入支付记录
            $stmt = $pdo->prepare("INSERT INTO pay_record (order_id, pay_no, pay_type, pay_amount, status, pay_time) VALUES (?, ?, ?, ?, 3, NOW())");
            $stmt->execute([$order_id, $pay_no, $pay_type, $pay_amount]);

            // 更新订单状态为已支付
            $stmt = $pdo->prepare("UPDATE order_main SET status = 2 WHERE id = ?");
            $stmt->execute([$order_id]);

            // 添加订单状态记录
            $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
            $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
            $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, 2, ?, ?, '订单支付完成')");
            $stmt->execute([$order_id, $operator_id, $operator_name]);

            // 提交事务
            $pdo->commit();

            $payment_success = true;
            $success = '支付成功！订单已进入处理阶段';
            record_log("完成订单支付：订单ID=$order_id");
        } catch (Exception $e) {
            // 回滚事务
            $pdo->rollBack();
            $error = '支付失败：' . $e->getMessage();
        }
    }
}

// 支付方式定义
$payment_methods = [
    1 => ['name' => '现金支付', 'description' => '顾客到门店使用现金支付'],
    2 => ['name' => '微信支付', 'description' => '使用微信扫码或微信小程序支付'],
    3 => ['name' => '支付宝支付', 'description' => '使用支付宝扫码支付'],
    4 => ['name' => '银行卡支付', 'description' => '使用银行卡POS机刷卡支付'],
    5 => ['name' => '会员余额支付', 'description' => '使用会员账户余额支付']
];

// 订单状态定义
$order_status = [
    1 => '待支付',
    2 => '待处理',
    3 => '制作中',
    4 => '已完成',
    5 => '已取消'
];

// 支付状态定义
$payment_status = [
    1 => '待支付',
    2 => '支付中',
    3 => '已支付',
    4 => '已退款'
];

// 获取订单信息
$order = null;
$order_items = [];
$payment_records = [];

if ($order_id > 0) {
    try {
        // 获取订单基本信息
        $stmt = $pdo->prepare("
            SELECT o.*, s.store_name, m.id as member_id, m.name as member_name, m.phone as member_phone, m.balance 
            FROM order_main o
            LEFT JOIN store_info s ON o.store_id = s.id
            LEFT JOIN mem_info m ON o.member_id = m.id
            WHERE o.id = ?
        ");
        $stmt->execute([$order_id]);
        $order = $stmt->fetch();

        if (!$order) {
            $error = '订单不存在或已被删除';
        } else {
            // 获取订单明细
            $stmt = $pdo->prepare("SELECT * FROM order_item WHERE order_id = ?");
            $stmt->execute([$order_id]);
            $order_items = $stmt->fetchAll();

            // 获取支付记录
            $stmt = $pdo->prepare("SELECT * FROM pay_record WHERE order_id = ? ORDER BY create_time DESC");
            $stmt->execute([$order_id]);
            $payment_records = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取订单信息失败：' . $e->getMessage();
    }
} else {
    // 获取待支付订单列表
    try {
        $stmt = $pdo->query("
            SELECT o.id, o.order_no, o.store_id, s.store_name, o.order_type, o.total_amount, o.discount_amount, o.pay_amount, 
                   o.member_id, m.name as member_name, o.create_time
            FROM order_main o
            LEFT JOIN store_info s ON o.store_id = s.id
            LEFT JOIN mem_info m ON o.member_id = m.id
            WHERE o.status = 1 /* 待支付状态 */
            ORDER BY o.create_time DESC
        ");
        $pending_orders = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取待支付订单列表失败：' . $e->getMessage();
        $pending_orders = [];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>支付管理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单与销售管理</a> &gt; 支付管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if ($payment_success): ?>
                <!-- 支付成功页面 -->
                <div class="info-box">
                    <h3>支付成功</h3>
                    <p>订单编号：<?php echo htmlspecialchars($order['order_no']); ?></p>
                    <p>支付金额：¥<?php echo number_format($order['pay_amount'], 2); ?></p>
                    <p>支付方式：<?php echo $payment_methods[$payment_records[0]['pay_type']]['name']; ?></p>
                    <p>支付时间：<?php echo date('Y-m-d H:i:s'); ?></p>
                </div>

                <div class="form-actions">
                    <a href="payment.php" class="btn btn-primary">返回支付管理</a>
                    <button onclick="window.print()" class="btn btn-success">打印小票</button>
                </div>
            <?php elseif ($order): ?>
                <?php if ($order['status'] > 1): ?>
                    <!-- 已支付订单 -->
                    <div class="info-box">
                        <h3>订单已支付</h3>
                        <p>该订单已完成支付，当前状态：<?php echo $order_status[$order['status']]; ?></p>
                        <p>订单编号：<?php echo htmlspecialchars($order['order_no']); ?></p>
                        <p>支付金额：¥<?php echo number_format($order['pay_amount'], 2); ?></p>
                        <?php if (!empty($payment_records)): ?>
                            <p>支付方式：<?php echo $payment_methods[$payment_records[0]['pay_type']]['name']; ?></p>
                            <p>支付时间：<?php echo $payment_records[0]['pay_time']; ?></p>
                        <?php endif; ?>
                    </div>

                    <div class="form-actions">
                        <a href="payment.php" class="btn btn-primary">返回支付管理</a>
                        <button onclick="window.print()" class="btn btn-success">打印小票</button>
                    </div>
                <?php else: ?>
                    <!-- 订单信息和支付表单 -->
                    <div class="info-box">
                        <h3>订单信息</h3>
                        <table class="info-table">
                            <tr>
                                <td width="120">订单编号：</td>
                                <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                <td width="120">门店：</td>
                                <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                            </tr>
                            <tr>
                                <td>订单类型：</td>
                                <td>
                                    <?php
                                    $types = [1 => '堂食', 2 => '外带', 3 => '外卖'];
                                    echo $types[$order['order_type']];
                                    ?>
                                </td>
                                <td>订单来源：</td>
                                <td>
                                    <?php
                                    $sources = [1 => '店员下单', 2 => '自助点单', 3 => '扫码点单', 4 => '外卖平台'];
                                    echo $sources[$order['order_source']];
                                    ?>
                                </td>
                            </tr>
                            <tr>
                                <td>会员信息：</td>
                                <td colspan="3">
                                    <?php if ($order['member_id']): ?>
                                        <?php echo htmlspecialchars($order['member_name']); ?> (<?php echo htmlspecialchars($order['member_phone']); ?>)
                                        <br>会员余额：¥<?php echo number_format($order['balance'], 2); ?>
                                    <?php else: ?>
                                        非会员
                                    <?php endif; ?>
                                </td>
                            </tr>
                            <tr>
                                <td>订单金额：</td>
                                <td>¥<?php echo number_format($order['total_amount'], 2); ?></td>
                                <td>优惠金额：</td>
                                <td>¥<?php echo number_format($order['discount_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>应付金额：</td>
                                <td colspan="3"><strong class="text-primary">¥<?php echo number_format($order['pay_amount'], 2); ?></strong></td>
                            </tr>
                            <tr>
                                <td>创建时间：</td>
                                <td colspan="3"><?php echo $order['create_time']; ?></td>
                            </tr>
                        </table>
                    </div>

                    <h3>订单明细</h3>
                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>产品名称</th>
                                    <th>属性</th>
                                    <th>单价</th>
                                    <th>数量</th>
                                    <th>小计</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($order_items as $item): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                        <td><?php echo htmlspecialchars($item['attributes'] ?: '无'); ?></td>
                                        <td>¥<?php echo number_format($item['price'], 2); ?></td>
                                        <td><?php echo $item['quantity']; ?></td>
                                        <td>¥<?php echo number_format($item['subtotal'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <td colspan="4" class="text-right"><strong>订单总额：</strong></td>
                                    <td>¥<?php echo number_format($order['total_amount'], 2); ?></td>
                                </tr>
                                <?php if ($order['discount_amount'] > 0): ?>
                                    <tr>
                                        <td colspan="4" class="text-right"><strong>优惠金额：</strong></td>
                                        <td>¥<?php echo number_format($order['discount_amount'], 2); ?></td>
                                    </tr>
                                <?php endif; ?>
                                <tr>
                                    <td colspan="4" class="text-right"><strong>应付金额：</strong></td>
                                    <td><strong class="text-primary">¥<?php echo number_format($order['pay_amount'], 2); ?></strong></td>
                                </tr>
                            </tfoot>
                        </table>
                    </div>

                    <h3>选择支付方式</h3>
                    <div class="form-container">
                        <form method="post" action="payment.php?order_id=<?php echo $order_id; ?>">
                            <input type="hidden" name="action" value="pay">
                            <input type="hidden" name="pay_amount" value="<?php echo $order['pay_amount']; ?>">
                            <?php if ($order['member_id']): ?>
                                <input type="hidden" name="member_id" value="<?php echo $order['member_id']; ?>">
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="pay_type">支付方式：</label>
                                <select id="pay_type" name="pay_type" class="form-control">
                                    <option value="0">-- 请选择支付方式 --</option>
                                    <?php foreach ($payment_methods as $id => $method): ?>
                                        <?php if (!($id == 5 && !$order['member_id'])): // 只有会员才能使用会员余额支付 
                                        ?>
                                            <option value="<?php echo $id; ?>">
                                                <?php echo $method['name']; ?> - <?php echo $method['description']; ?>
                                                <?php if ($id == 5 && $order['member_id']): ?>
                                                    (当前余额: ¥<?php echo number_format($order['balance'], 2); ?>)
                                                <?php endif; ?>
                                            </option>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-success">确认支付</button>
                                <a href="payment.php" class="btn btn-secondary">返回支付管理</a>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>
            <?php else: ?>
                <!-- 待支付订单列表 -->
                <h3>待支付订单列表</h3>
                <?php if (empty($pending_orders)): ?>
                    <div class="info-box">
                        <p>暂无待支付订单</p>
                    </div>
                <?php else: ?>
                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>订单编号</th>
                                    <th>门店</th>
                                    <th>订单类型</th>
                                    <th>会员</th>
                                    <th>订单金额</th>
                                    <th>应付金额</th>
                                    <th>创建时间</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($pending_orders as $order): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                                        <td>
                                            <?php
                                            $types = [1 => '堂食', 2 => '外带', 3 => '外卖'];
                                            echo $types[$order['order_type']];
                                            ?>
                                        </td>
                                        <td>
                                            <?php echo $order['member_id'] ? htmlspecialchars($order['member_name']) : '非会员'; ?>
                                        </td>
                                        <td>¥<?php echo number_format($order['total_amount'], 2); ?></td>
                                        <td>¥<?php echo number_format($order['pay_amount'], 2); ?></td>
                                        <td><?php echo $order['create_time']; ?></td>
                                        <td>
                                            <a href="payment.php?order_id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">去支付</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>