<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order.process');

// 记录访问日志
record_log('访问订单处理页面');

// 处理订单状态更新
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'update_status') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($order_id > 0 && $new_status > 0) {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 更新订单状态
                $stmt = $pdo->prepare("UPDATE order_main SET status = ? WHERE id = ?");
                $stmt->execute([$new_status, $order_id]);

                // 记录状态变更
                $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';

                // 根据状态生成默认备注
                if (empty($remark)) {
                    switch ($new_status) {
                        case 2:
                            $remark = '订单已支付，等待处理';
                            break;
                        case 3:
                            $remark = '订单开始制作';
                            break;
                        case 4:
                            $remark = '订单制作完成，等待取餐';
                            break;
                        case 5:
                            $remark = '订单已取消';
                            break;
                        case 6:
                            $remark = '订单已完成，顾客已取餐';
                            break;
                        default:
                            $remark = '订单状态更新';
                    }
                }

                $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, ?, ?, ?, ?)");
                $stmt->execute([$order_id, $new_status, $operator_id, $operator_name, $remark]);

                // 提交事务
                $pdo->commit();

                // 记录日志
                record_log("更新订单状态：订单ID=$order_id，新状态=$new_status");

                $success = '订单状态更新成功！';
            } catch (PDOException $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = '订单状态更新失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID或状态！';
        }
    } elseif ($_POST['action'] == 'call_customer') {
        // 处理叫号
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $call_method = isset($_POST['call_method']) ? trim($_POST['call_method']) : 'screen';

        if ($order_id > 0) {
            try {
                // 获取订单信息
                $stmt = $pdo->prepare("SELECT order_no, member_id FROM order_main WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if ($order) {
                    // 记录叫号操作到order_status表
                    $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                    $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                    $call_remark = $call_method == 'sms' ? '短信通知取餐' : '屏幕叫号取餐';

                    $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, 4, ?, ?, ?)");
                    $stmt->execute([$order_id, $operator_id, $operator_name, $call_remark]);

                    // 如果是短信叫号且有会员信息，则发送短信
                    if ($call_method == 'sms' && $order['member_id']) {
                        // 获取会员手机号
                        $stmt = $pdo->prepare("SELECT phone FROM mem_info WHERE id = ?");
                        $stmt->execute([$order['member_id']]);
                        $member = $stmt->fetch();

                        if ($member && !empty($member['phone'])) {
                            // TODO: 实际的短信发送逻辑
                            // 这里只是模拟短信发送成功
                            record_log("向会员ID={$order['member_id']}发送订单取餐短信通知，订单编号：{$order['order_no']}");
                        }
                    }

                    $success = '取餐叫号成功！';
                    record_log("订单取餐叫号：订单ID=$order_id，叫号方式=$call_method");
                } else {
                    $error = '订单不存在！';
                }
            } catch (PDOException $e) {
                $error = '取餐叫号失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID！';
        }
    }
}

// 获取要处理的订单列表
$orders = [];
try {
    // 默认显示待处理和制作中的订单
    $status_filter = isset($_GET['status']) ? $_GET['status'] : null;

    // 构建查询条件
    $where_conditions = [];
    $params = [];

    if ($status_filter !== null && is_numeric($status_filter)) {
        $where_conditions[] = "o.status = ?";
        $params[] = intval($status_filter);
    } else {
        // 默认显示待处理、制作中和已完成（未取餐）的订单
        $where_conditions[] = "o.status IN (2, 3, 4)";
    }

    // 如果有门店筛选
    $store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
    if ($store_id > 0) {
        $where_conditions[] = "o.store_id = ?";
        $params[] = $store_id;
    }

    // 构建完整WHERE子句
    $where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

    // 查询订单数据 - 移除对order_call表的引用
    $sql = "
        SELECT o.*, s.store_name, m.name as member_name, m.phone as member_phone
        FROM order_main o
        LEFT JOIN store_info s ON o.store_id = s.id
        LEFT JOIN mem_info m ON o.member_id = m.id
        $where_clause
        ORDER BY 
            CASE 
                WHEN o.status = 2 THEN 1 
                WHEN o.status = 3 THEN 2 
                WHEN o.status = 4 THEN 3 
                ELSE 4 
            END,
            o.create_time DESC
    ";

    $stmt = $pdo->prepare($sql);
    if (!empty($params)) {
        $stmt->execute($params);
    } else {
        $stmt->execute();
    }

    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取订单列表失败：' . $e->getMessage();
}

// 获取所有门店列表，用于筛选
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info WHERE status = 1 ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 订单状态定义
$order_status = [
    1 => '待支付',
    2 => '待处理',
    3 => '制作中',
    4 => '已完成',
    5 => '已取消',
    6 => '已取餐'
];

// 订单类型定义
$order_types = [
    1 => '堂食',
    2 => '外带',
    3 => '外卖'
];

// 订单来源定义
$order_sources = [
    1 => '店员下单',
    2 => '自助点单',
    3 => '扫码点单',
    4 => '外卖平台'
];

// 获取单个订单详情（如果指定了order_id参数）
$order_details = null;
$order_items = [];
$order_status_history = [];

if (isset($_GET['view']) && $_GET['view'] == 'details' && isset($_GET['order_id'])) {
    $detail_order_id = intval($_GET['order_id']);

    try {
        // 获取订单基本信息
        $stmt = $pdo->prepare("
            SELECT o.*, s.store_name, m.name as member_name, m.phone as member_phone
            FROM order_main o
            LEFT JOIN store_info s ON o.store_id = s.id
            LEFT JOIN mem_info m ON o.member_id = m.id
            WHERE o.id = ?
        ");
        $stmt->execute([$detail_order_id]);
        $order_details = $stmt->fetch();

        if ($order_details) {
            // 获取订单明细
            $stmt = $pdo->prepare("SELECT * FROM order_item WHERE order_id = ?");
            $stmt->execute([$detail_order_id]);
            $order_items = $stmt->fetchAll();

            // 获取订单状态历史
            $stmt = $pdo->prepare("
                SELECT * FROM order_status 
                WHERE order_id = ? 
                ORDER BY create_time DESC
            ");
            $stmt->execute([$detail_order_id]);
            $order_status_history = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取订单详情失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单处理</h2>
            <div class="breadcrumb">
                <a href="index.php">订单与销售管理</a> &gt; 订单处理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <?php if (isset($_GET['view']) && $_GET['view'] == 'details' && $order_details): ?>
                <!-- 订单详情视图 -->
                <div class="action-bar">
                    <a href="process.php" class="btn btn-secondary">返回订单列表</a>

                    <?php if ($order_details['status'] == 2): ?>
                        <form method="post" action="process.php" class="inline-form">
                            <input type="hidden" name="action" value="update_status">
                            <input type="hidden" name="order_id" value="<?php echo $order_details['id']; ?>">
                            <input type="hidden" name="new_status" value="3">
                            <button type="submit" class="btn btn-primary">开始制作</button>
                        </form>
                    <?php elseif ($order_details['status'] == 3): ?>
                        <form method="post" action="process.php" class="inline-form">
                            <input type="hidden" name="action" value="update_status">
                            <input type="hidden" name="order_id" value="<?php echo $order_details['id']; ?>">
                            <input type="hidden" name="new_status" value="4">
                            <button type="submit" class="btn btn-success">完成制作</button>
                        </form>
                    <?php elseif ($order_details['status'] == 4): ?>
                        <form method="post" action="process.php" class="inline-form">
                            <input type="hidden" name="action" value="call_customer">
                            <input type="hidden" name="order_id" value="<?php echo $order_details['id']; ?>">
                            <input type="hidden" name="call_method" value="screen">
                            <button type="submit" class="btn btn-primary">屏幕叫号</button>
                        </form>

                        <?php if ($order_details['member_id']): ?>
                            <form method="post" action="process.php" class="inline-form">
                                <input type="hidden" name="action" value="call_customer">
                                <input type="hidden" name="order_id" value="<?php echo $order_details['id']; ?>">
                                <input type="hidden" name="call_method" value="sms">
                                <button type="submit" class="btn btn-primary">短信通知</button>
                            </form>
                        <?php endif; ?>

                        <form method="post" action="process.php" class="inline-form">
                            <input type="hidden" name="action" value="update_status">
                            <input type="hidden" name="order_id" value="<?php echo $order_details['id']; ?>">
                            <input type="hidden" name="new_status" value="6">
                            <button type="submit" class="btn btn-success">确认取餐完成</button>
                        </form>
                    <?php endif; ?>
                </div>

                <div class="info-box">
                    <h3>订单基本信息</h3>
                    <table class="info-table">
                        <tr>
                            <td width="120">订单编号：</td>
                            <td><?php echo htmlspecialchars($order_details['order_no']); ?></td>
                            <td width="120">门店：</td>
                            <td><?php echo htmlspecialchars($order_details['store_name']); ?></td>
                        </tr>
                        <tr>
                            <td>订单类型：</td>
                            <td><?php echo $order_types[$order_details['order_type']]; ?></td>
                            <td>订单来源：</td>
                            <td><?php echo $order_sources[$order_details['order_source']]; ?></td>
                        </tr>
                        <tr>
                            <td>会员信息：</td>
                            <td colspan="3">
                                <?php if ($order_details['member_id']): ?>
                                    <?php echo htmlspecialchars($order_details['member_name']); ?>
                                    (<?php echo htmlspecialchars($order_details['member_phone']); ?>)
                                <?php else: ?>
                                    非会员
                                <?php endif; ?>
                            </td>
                        </tr>
                        <tr>
                            <td>订单状态：</td>
                            <td>
                                <?php
                                $bg_color = '';
                                switch ($order_details['status']) {
                                    case 1:
                                    case 2:
                                        $bg_color = '#ffc107'; // 黄色
                                        break;
                                    case 3:
                                        $bg_color = '#007bff'; // 蓝色
                                        break;
                                    case 4:
                                    case 6:
                                        $bg_color = '#28a745'; // 绿色
                                        break;
                                    case 5:
                                        $bg_color = '#dc3545'; // 红色
                                        break;
                                }
                                ?>
                                <span class="status-tag" style="background-color: <?php echo $bg_color; ?>;">
                                    <?php echo $order_status[$order_details['status']]; ?>
                                </span>
                            </td>
                            <td>创建时间：</td>
                            <td><?php echo $order_details['create_time']; ?></td>
                        </tr>
                        <tr>
                            <td>订单金额：</td>
                            <td>¥<?php echo number_format($order_details['total_amount'], 2); ?></td>
                            <td>应付金额：</td>
                            <td>¥<?php echo number_format($order_details['pay_amount'], 2); ?></td>
                        </tr>
                    </table>
                </div>

                <h3>订单明细</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>属性</th>
                                <th>单价</th>
                                <th>数量</th>
                                <th>小计</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($order_items as $item): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                    <td><?php echo htmlspecialchars($item['attributes'] ?: '无'); ?></td>
                                    <td>¥<?php echo number_format($item['price'], 2); ?></td>
                                    <td><?php echo $item['quantity']; ?></td>
                                    <td>¥<?php echo number_format($item['subtotal'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="4" class="text-right"><strong>订单总额：</strong></td>
                                <td>¥<?php echo number_format($order_details['total_amount'], 2); ?></td>
                            </tr>
                            <?php if ($order_details['discount_amount'] > 0): ?>
                                <tr>
                                    <td colspan="4" class="text-right"><strong>优惠金额：</strong></td>
                                    <td>¥<?php echo number_format($order_details['discount_amount'], 2); ?></td>
                                </tr>
                            <?php endif; ?>
                            <tr>
                                <td colspan="4" class="text-right"><strong>应付金额：</strong></td>
                                <td><strong>¥<?php echo number_format($order_details['pay_amount'], 2); ?></strong></td>
                            </tr>
                        </tfoot>
                    </table>
                </div>

                <h3>订单状态历史与叫号记录</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>时间</th>
                                <th>操作类型</th>
                                <th>操作人</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($order_status_history as $history): ?>
                                <tr>
                                    <td><?php echo $history['create_time']; ?></td>
                                    <td>
                                        <?php
                                        // 识别是叫号操作还是状态变更
                                        if (strpos($history['remark'], '叫号') !== false || strpos($history['remark'], '通知') !== false) {
                                            echo '<span class="status-tag" style="background-color: #007bff;">取餐通知</span>';
                                        } else {
                                            $bg_color = '';
                                            switch ($history['status']) {
                                                case 1:
                                                case 2:
                                                    $bg_color = '#ffc107'; // 黄色
                                                    break;
                                                case 3:
                                                    $bg_color = '#007bff'; // 蓝色
                                                    break;
                                                case 4:
                                                case 6:
                                                    $bg_color = '#28a745'; // 绿色
                                                    break;
                                                case 5:
                                                    $bg_color = '#dc3545'; // 红色
                                                    break;
                                            }
                                            echo '<span class="status-tag" style="background-color: ' . $bg_color . ';">' . $order_status[$history['status']] . '</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($history['operator_name']); ?></td>
                                    <td><?php echo htmlspecialchars($history['remark']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

            <?php else: ?>
                <!-- 订单列表视图 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="status">订单状态：</label>
                                <select id="status" name="status" onchange="this.form.submit()">
                                    <option value="">全部处理中</option>
                                    <option value="2" <?php echo (isset($_GET['status']) && $_GET['status'] == '2') ? 'selected' : ''; ?>>待处理</option>
                                    <option value="3" <?php echo (isset($_GET['status']) && $_GET['status'] == '3') ? 'selected' : ''; ?>>制作中</option>
                                    <option value="4" <?php echo (isset($_GET['status']) && $_GET['status'] == '4') ? 'selected' : ''; ?>>已完成（待取餐）</option>
                                    <option value="6" <?php echo (isset($_GET['status']) && $_GET['status'] == '6') ? 'selected' : ''; ?>>已取餐</option>
                                    <option value="5" <?php echo (isset($_GET['status']) && $_GET['status'] == '5') ? 'selected' : ''; ?>>已取消</option>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="store_id">门店：</label>
                                <select id="store_id" name="store_id" onchange="this.form.submit()">
                                    <option value="">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo (isset($_GET['store_id']) && $_GET['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="process.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>门店</th>
                                <th>类型</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>客户</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($orders)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无需要处理的订单</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($orders as $order): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                                        <td><?php echo $order_types[$order['order_type']]; ?></td>
                                        <td>¥<?php echo number_format($order['pay_amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $bg_color = '';
                                            switch ($order['status']) {
                                                case 1:
                                                case 2:
                                                    $bg_color = '#ffc107'; // 黄色
                                                    break;
                                                case 3:
                                                    $bg_color = '#007bff'; // 蓝色
                                                    break;
                                                case 4:
                                                case 6:
                                                    $bg_color = '#28a745'; // 绿色
                                                    break;
                                                case 5:
                                                    $bg_color = '#dc3545'; // 红色
                                                    break;
                                            }
                                            ?>
                                            <span class="status-tag" style="background-color: <?php echo $bg_color; ?>;">
                                                <?php echo $order_status[$order['status']]; ?>
                                            </span>
                                        </td>
                                        <td>
                                            <?php if ($order['member_id']): ?>
                                                <?php echo htmlspecialchars($order['member_name']); ?>
                                            <?php else: ?>
                                                非会员
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo (new DateTime($order['create_time']))->format('m-d H:i'); ?></td>
                                        <td>
                                            <a href="process.php?view=details&order_id=<?php echo $order['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                            <?php if ($order['status'] == 2): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="update_status">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                    <input type="hidden" name="new_status" value="3">
                                                    <button type="submit" class="btn btn-sm btn-primary">开始制作</button>
                                                </form>
                                            <?php elseif ($order['status'] == 3): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="update_status">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                    <input type="hidden" name="new_status" value="4">
                                                    <button type="submit" class="btn btn-sm btn-success">完成制作</button>
                                                </form>
                                            <?php elseif ($order['status'] == 4): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="call_customer">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                    <input type="hidden" name="call_method" value="screen">
                                                    <button type="submit" class="btn btn-sm btn-primary">叫号</button>
                                                </form>

                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="update_status">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                                    <input type="hidden" name="new_status" value="6">
                                                    <button type="submit" class="btn btn-sm btn-success">取餐完成</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 自动刷新页面，确保订单状态及时更新
        <?php if (!isset($_GET['view']) || $_GET['view'] != 'details'): ?>
            setTimeout(function() {
                location.reload();
            }, 60000); // 每60秒刷新一次
        <?php endif; ?>
    </script>
</body>

</html>