<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product.category');

// 记录访问日志
record_log('访问产品分类管理页面');

// 添加/编辑分类处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加分类
    if ($_POST['action'] == 'add') {
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $parent_id = isset($_POST['parent_id']) ? intval($_POST['parent_id']) : 0;
        $sort_order = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($name)) {
            $error = '请填写分类名称！';
        } else {
            try {
                // 检查分类名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_category WHERE name = ? AND parent_id = ?");
                $stmt->execute([$name, $parent_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '该分类名称已存在！';
                } else {
                    // 添加分类
                    $stmt = $pdo->prepare("INSERT INTO product_category (name, parent_id, sort_order, status) VALUES (?, ?, ?, ?)");
                    $result = $stmt->execute([$name, $parent_id, $sort_order, $status]);

                    if ($result) {
                        record_log("添加产品分类：{$name}");
                        $success = '分类添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: category.php?success=add');
                        exit;
                    } else {
                        $error = '分类添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑分类
    elseif ($_POST['action'] == 'edit') {
        $category_id = isset($_POST['category_id']) ? intval($_POST['category_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $parent_id = isset($_POST['parent_id']) ? intval($_POST['parent_id']) : 0;
        $sort_order = isset($_POST['sort_order']) ? intval($_POST['sort_order']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($category_id <= 0 || empty($name)) {
            $error = '请填写完整分类信息！';
        } elseif ($category_id == $parent_id) {
            $error = '父分类不能选择自己！';
        } else {
            try {
                // 检查是否选择自己的子分类作为父分类（防止循环）
                $is_valid_parent = true;
                if ($parent_id > 0) {
                    $stmt = $pdo->prepare("SELECT parent_id FROM product_category WHERE id = ?");
                    $stmt->execute([$parent_id]);
                    $parent = $stmt->fetch();

                    // 检查所选父分类是否为当前分类的子分类
                    if ($parent && $parent['parent_id'] == $category_id) {
                        $is_valid_parent = false;
                    }
                }

                if (!$is_valid_parent) {
                    $error = '不能选择当前分类的子分类作为父分类！';
                } else {
                    // 检查分类名称是否已被其他分类使用
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_category WHERE name = ? AND parent_id = ? AND id != ?");
                    $stmt->execute([$name, $parent_id, $category_id]);
                    $result = $stmt->fetch();

                    if ($result['count'] > 0) {
                        $error = '该分类名称已被其他分类使用！';
                    } else {
                        // 更新分类信息
                        $stmt = $pdo->prepare("UPDATE product_category SET name = ?, parent_id = ?, sort_order = ?, status = ? WHERE id = ?");
                        $result = $stmt->execute([$name, $parent_id, $sort_order, $status, $category_id]);

                        if ($result) {
                            record_log("编辑产品分类：{$name}");
                            $success = '分类信息更新成功！';
                            // 重定向到没有参数的页面
                            header('Location: category.php?success=edit');
                            exit;
                        } else {
                            $error = '分类信息更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除分类
    elseif ($_POST['action'] == 'delete') {
        $category_id = isset($_POST['category_id']) ? intval($_POST['category_id']) : 0;

        if ($category_id <= 0) {
            $error = '无效的分类ID！';
        } else {
            try {
                // 获取分类名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM product_category WHERE id = ?");
                $stmt->execute([$category_id]);
                $category = $stmt->fetch();

                if (!$category) {
                    $error = '分类不存在！';
                } else {
                    // 检查分类是否有子分类
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_category WHERE parent_id = ?");
                    $stmt->execute([$category_id]);
                    $sub_category = $stmt->fetch();

                    if ($sub_category['count'] > 0) {
                        $error = '该分类下存在子分类，无法删除！';
                    } else {
                        // 检查分类是否有关联产品
                        $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_items WHERE category = ?");
                        $stmt->execute([$category_id]);
                        $products = $stmt->fetch();

                        if ($products['count'] > 0) {
                            $error = '该分类下存在产品，无法删除！';
                        } else {
                            // 删除分类
                            $stmt = $pdo->prepare("DELETE FROM product_category WHERE id = ?");
                            $result = $stmt->execute([$category_id]);

                            if ($result) {
                                record_log("删除产品分类：{$category['name']}");
                                $success = '分类删除成功！';
                            } else {
                                $error = '分类删除失败！';
                            }
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有分类
try {
    $stmt = $pdo->query("
        SELECT c.*, p.name as parent_name 
        FROM product_category c
        LEFT JOIN product_category p ON c.parent_id = p.id
        ORDER BY c.parent_id, c.sort_order
    ");
    $categories = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取分类列表失败：' . $e->getMessage();
    $categories = [];
}

// 判断是否显示表单
$show_form = false;
$edit_category = null;

// 编辑分类时显示表单并获取分类信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM product_category WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_category = $stmt->fetch();
        if (!$edit_category) {
            $error = '分类不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取分类信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加分类时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '分类添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '分类信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>产品分类管理</h2>
            <div class="breadcrumb">
                <a href="index.php">产品管理</a> &gt; 分类管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="category.php?action=add" class="btn btn-add">添加分类</a>
            </div>

            <!-- 添加/编辑分类表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_category ? '编辑分类' : '添加分类'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_category ? 'edit' : 'add'; ?>">
                        <?php if ($edit_category): ?>
                            <input type="hidden" name="category_id" value="<?php echo $edit_category['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name">分类名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_category ? htmlspecialchars($edit_category['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="parent_id">父分类：</label>
                            <select id="parent_id" name="parent_id">
                                <option value="0">-- 无父分类（顶级分类）--</option>
                                <?php
                                foreach ($categories as $cat):
                                    // 编辑时，不显示当前分类及其子分类作为父分类选项
                                    if (!$edit_category || ($cat['id'] != $edit_category['id'] && $cat['parent_id'] != $edit_category['id'])):
                                ?>
                                        <option value="<?php echo $cat['id']; ?>" <?php echo ($edit_category && $edit_category['parent_id'] == $cat['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($cat['name']); ?>
                                        </option>
                                <?php
                                    endif;
                                endforeach;
                                ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="sort_order">排序：</label>
                            <input type="number" id="sort_order" name="sort_order" min="0" value="<?php echo $edit_category ? $edit_category['sort_order'] : '0'; ?>">
                            <small>数字越小排序越靠前</small>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_category && $edit_category['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo ($edit_category && $edit_category['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="category.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 分类列表 -->
            <div class="table-container">
                <h3>分类列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>分类名称</th>
                            <th>父分类</th>
                            <th>排序</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($categories)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无分类数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($categories as $category): ?>
                                <tr>
                                    <td><?php echo $category['id']; ?></td>
                                    <td><?php echo htmlspecialchars($category['name']); ?></td>
                                    <td><?php echo $category['parent_id'] > 0 ? htmlspecialchars($category['parent_name']) : '无（顶级分类）'; ?></td>
                                    <td><?php echo $category['sort_order']; ?></td>
                                    <td>
                                        <?php
                                        if ($category['status'] == 1) {
                                            echo '<span class="status-active">启用</span>';
                                        } else {
                                            echo '<span class="status-inactive">禁用</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $category['create_time']; ?></td>
                                    <td>
                                        <a href="category.php?action=edit&id=<?php echo $category['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="category_id" value="<?php echo $category['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除分类 \'<?php echo htmlspecialchars($category['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>